<?php


/**
 * Helper to get the region state.
 * 
 * Returns a list of all theme regions with the current working region set to
 * TRUE. Region groups are also checked.
 * 
 * Use the following within a preprocess function related to blocks.
 * 
 * For "blocks" (plural)
 * 
 *  extract(hex_canvas_region_states($vars['region']), EXTR_PREFIX_ALL, 'is');
 * 
 * Or "block" (singular)
 * 
 *  extract(hex_canvas_region_states($vars['block']->region), EXTR_PREFIX_ALL, 'is');
 * 
 *  if ($is_sidebar) {
 *    // code
 *  }
 * 
 */
function hex_canvas_region_states($region) {
  static $defaults;

  if (!isset($defaults)) {
    // Set defaults.
    foreach (array_keys(system_region_list(hex_active_theme())) as $region_key) {
      $defaults[$region_key] = FALSE;
    }
    foreach (array_keys(hex_theme_info('region groups', array())) as $group_key) {
      $defaults[$group_key] = FALSE;
    }
  }
  $regions = $defaults;

  // Set actual state.
  $regions[$region] = TRUE;
  if (hex_plugin_exists('region_groups') && $group = region_groups_get_group($region)) {
    $regions[$group] = TRUE;
  }

  return $regions;
}

