<?php

define('HEX_BASE_COMPATIBILITY', '1.x');

/**
 * Returns plug-in data.
 */
function _hex_build_plugins() {

  // Needed for hex_file_scan().
  include_once hex_theme_path('hex') . '/includes/build_file_paths.inc';

  foreach (list_themes() as $theme => $theme_data) {
    $theme_paths[$theme] = dirname($theme_data->filename);
  }
  // This path will be cut down in the next loop.
  $_ignore_paths = $theme_paths;

  // Set defaults.
  $defaults = array(
    'name' => '',
    'description' => '',
    'dependencies' => array(),
    'dependencies_defined' => array(),
    'dependencies_missing' => array(),
    'dependents' => array(),
    'version' => NULL,
    'php' => DRUPAL_MINIMUM_PHP,
    'hex' => NULL,
  );

  // Gather and build data of all available plug-in's held in each active theme.
  $plugins = array();

  foreach (hex_active_themes() as $theme) {

    // Prevent the base theme from scanning child themes or any other theme
    // that could possibly be inactive and live within the base theme.
    unset($_ignore_paths[$theme]);

    foreach (hex_file_scan($theme_paths[$theme] ,'^[a-zA-Z0-9_-]+\.pinfo$', $_ignore_paths) as $pinfo_name => $pinfo_paths) {
      $pinfo_path = $pinfo_paths[0];

      // Strip extensions.
      $plugin = substr($pinfo_name, 0, strrpos($pinfo_name, '.'));

      // The first base theme to host the plug-in maintains its ownership.
      if (isset($plugins[$plugin])) {
        continue;
      }

      // Parse .pinfo meta data.
      $plugins[$plugin]->info = drupal_parse_info_file($pinfo_path) + $defaults;

      // Theme hosting the plug-in.
      $plugins[$plugin]->info['owner'] = $theme;

      // The plugin itself.
      $plugins[$plugin]->plugin_path = dirname($pinfo_path);
      $plugins[$plugin]->file_path = $pinfo_path;
    }
  }

  // Alphabetical sort.
  ksort($plugins);

  // This core function was made for modules but it's generic enough to use
  // for plug-in's. It builds dependency data to be processed below.
  $plugins = _module_build_dependencies($plugins);
  // Build list of missing dependencies.
  // TODO: Add a notice when dependencies are missing to avoid confusion.
  // If any of the dependencies are missing, the theme enabled plug-in
  // will not load at all. Currently, it's silent about it.
  // 
  // The error should be given in the space provided in the next two blocks.

  // Find missing dependencies.
  // TODO: also check for incompatible by hex version, maybe?
  $plugins_missing = array();
  foreach ($plugins as $plugin => $plugin_data) {
    foreach ($plugin_data->info['dependencies'] as $dependency) {
      if (!isset($plugins[$dependency])) {
        $plugins[$plugin]->info['dependencies_missing'][] = $dependency;
      }
    }
  }

  // Build list for plug-ins created for module compatibility.
  // These will automatically load.
  $activate = array();
  foreach (module_list() as $module) {
    if (isset($plugins[$module . '_module'])) {
      $activate[] = $module . '_module';
    }
  }
  // Get theme enabled plug-ins.
  // Name space for hex specific plugins to prevent conflicts. This cannot be
  // mixed with the generic 'plugins' key. Use one or the other but in future
  // versions this should always be used.
  if ($hex_plugins = hex_theme_info('hex plugins', array())) {
    $activate = array_merge($activate, $hex_plugins);
  }
  else {
    // The plugins key can conflict with modules/themes that depend on CTools
    // but they are always multi-dimensional. The following verifies that it's
    // a flat array specific to hexagon's plugin switch. This should be
    // depreicated in future revisions.
    // TODO: remove in next major version.
    foreach (hex_theme_info('plugins', array()) as $i => $plugin) {
      if (is_numeric($i) && is_string($plugin)) {
        $activate[] = $plugin;
      }
    }
  }

  // Get enabled plug-in's as they are defined from the active theme.
  // There is no inheritance for the state of plug-in's set from .info.
  $plugins_active = array();
  foreach ($activate as $active) {
    if (isset($plugins[$active]) && empty($plugins[$active]->info['dependencies_missing'])) {
      $activate = array();
      foreach ($plugins[$active]->info['dependencies'] as $dependency) {
        if (!empty($plugins[$dependency]->info['dependencies_missing'])) {
          continue 2;
        }
        $activate[$dependency] = $plugins[$dependency];
      }
      $activate[$active] = $plugins[$active];
      $plugins_active += $activate;
    }
    else {
      if (isset($plugins[$active])) {
        drupal_set_message(t('The theme plug-in "!title" was not loaded. It is missing a dependency.', array('!title' => $plugins[$active]->info['name'])));
      }
      else {
        drupal_set_message(t('The theme plug-in key \'<code>!title</code>\' was not set to any available plug-in. Check the .info file for the active theme.', array('!title' => $active)));
      }
    }
  }

  // Finally, add active dependents or child plug-ins that are enabled.
  foreach ($plugins_active as $plugin_key => $plugin_data) {
    if (!empty($plugin_data->info['dependents'])) {
      foreach ($plugin_data->info['dependents'] as $dependent) {
        if (isset($plugins_active[$dependent])) {
          $plugins_active[$plugin_key]->info['active_dependents'][] = $dependent;
        }
      }
    }
  }

  // Alphabetical sort.
  ksort($plugins_active);

  return array('active' => $plugins_active, 'all' => $plugins, 'module_list' => module_list());
}

