<?php

/**
 * Get info data specific to a given plug-in. The information will be pulled
 * from the plug-in's .pinfo file.
 * 
 * @param $plugin
 *  (required) The plug-in to target.
 * @param $pinfo_key
 *  (required) The .pinfo key in the plug-in.
 * @param $default
 *  (optional) Default value if none is found.
 */
function hex_plugin_info($plugin, $pinfo_key, $default = NULL) {

  $plugins = _hex_cache('plugins');
  if (isset($plugins['all'][$plugin]->info[$pinfo_key])) {
    $plugin_info = $plugins['all'][$plugin]->info[$pinfo_key];
  }

  // Pass through defauts.
  if (!isset($plugin_info)) {
    $plugin_info = $default;
  }

  return $plugin_info;
}

/**
 * Check to see if a plug-in exists and is active.
 */
function hex_plugin_exists($plugin) {
  return in_array($plugin, hex_plugin_list());
}

/**
 * Return the path to a given plug-in.
 * 
 * If there are multiple copies of a plug-in with the same name that exists
 * across base themes and sub-themes, the returned path will point to the most
 * active, i.e., the active sub-theme or the sub-theme closest to the current
 * theme hosting the plug-in.
 * 
 * @param $plugin
 *  (required) The plug-in name. If there's no match the function will return
 *  an empty string.
 */
function hex_plugin_path($plugin) {
  $plugins = _hex_cache('plugins');
  return isset($plugins['all'][$plugin]) ? $plugins['all'][$plugin]->plugin_path : NULL;
}

/**
 * Returns a list of plug-in's.
 * 
 * @param $set
 *  Can either be 'active' for the active set or 'all' for all discovered
 *  plug-in's. The all set will not include plug-in's hosted in disabled themes.
 */
function hex_plugin_list($set = 'active') {
  $list = array();
  $plugins = _hex_cache('plugins');
  foreach (array_keys($plugins[$set]) as $plugin) {
    $list[$plugin] = $plugin;
  }
  return $list;
}

/**
 * Return a list of plug-in's specific to an owner (theme hosting the plug-in).
 * 
 * @param $theme
 *  The theme key. Must be active.
 * @param $get
 *  Either 'all' or 'active' (default).
 */
function hex_plugin_list_by_owner($theme, $get = 'active') {
  $list = array();
  $plugins = _hex_cache('plugins');
  foreach ($plugins[$get] as $plugin => $plugin_data) {
    if ($plugin_data->info['owner'] == $theme) {
      $list[$plugin] = $plugin;
    }
  }
  return $list;
}

/**
 * Simply returns a list of modules fetched when the plug-in data was built.
 * Used to compare with module_list() and force a refresh when it differs.
 */
function hex_plugin_module_state() {
  $plugins = _hex_cache('plugins');
  return $plugins['module_list'];
}