<?php

/**
 * Changed "div" tag to "p" and removed brackets. Also uses proper ellipses.
 */
function hex_more_help_link($url) {
  return '<p class="more-help-link">'. t('<a href="@link">more help…</a>', array('@link' => check_url($url))) .'</p>';
}

/**
 * Added differentiating class for active menu trails vs. active menu items.
 */
function hex_menu_item($link, $has_children, $menu = '', $in_active_trail = FALSE, $extra_class = NULL) {
  $class = ($menu ? 'expanded' : ($has_children ? 'collapsed' : 'leaf'));
  if ($in_active_trail) {
    $class .= ($has_children ? ' active-trail' : ' active-menu');
  }
  if (!empty($extra_class)) {
    $class .= ' '. $extra_class;
  }
  return '<li class="'. $class .'">'. $link . $menu ."</li>\n";
}

/**
 * Format a set of radio buttons. Overridden so it always wraps in
 * theme_form_element. This helps consistency in spacing through css.
 *
 * @param $element
 *   An associative array containing the properties of the element.
 *   Properties used: title, value, options, description, required and attributes.
 * @return
 *   A themed HTML string representing the radio button set.
 *
 * @ingroup themeable
 */
function hex_radios($element) {
  $class = 'form-radios';
  if (isset($element['#attributes']['class'])) {
    $class .= ' '. $element['#attributes']['class'];
  }
  $element['#children'] = '<div class="'. $class .'">'. (!empty($element['#children']) ? $element['#children'] : '') .'</div>';

  unset($element['#id']);
  return theme('form_element', $element, $element['#children']);
}

/**
 * Format a set of checkboxes. Overridden so it always wraps in
 * theme_form_element. This helps consistency in spacing through css.
 *
 * @param $element
 *   An associative array containing the properties of the element.
 * @return
 *   A themed HTML string representing the checkbox set.
 *
 * @ingroup themeable
 */
function hex_checkboxes($element) {
  $class = 'form-checkboxes';
  if (isset($element['#attributes']['class'])) {
    $class .= ' '. $element['#attributes']['class'];
  }
  $element['#children'] = '<div class="'. $class .'">'. (!empty($element['#children']) ? $element['#children'] : '') .'</div>';

  unset($element['#id']);
  return theme('form_element', $element, $element['#children']);
}

/**
 * Phase 2 page template variables preprocessor.
 */
function hex_preprocess_page(&$vars) {
  // Form an image element by passing it through theme('image').
  // This will apply a height and width which will render the page more consistently.
  // Since logo's are usually placed on top of the page, not having dimention can have
  // create a inconsistent state for everything below it on low bandwidth connections.
  $vars['logo_img'] = '';
  if (hex_setting('toggle_logo', 1)) {
    if (!hex_setting('default_logo', 1)) {
      // Chop path so theme_image accepts.
      $logo_path = strpos($vars['logo'], base_path()) === 0 ? substr($vars['logo'], strlen(base_path())) : $vars['logo'];
    }
    // Discover the file based on the base name.
    elseif ($logo_path = hex_path_to_file(basename($vars['logo']))) {
      // Reset the default logo var.
      $vars['logo'] = base_path() . $logo_path;
    }
    if (!empty($logo_path)) {
      $vars['logo_img']  = theme('image', $logo_path, t('logo'), $vars['site_name'], array('class' => 'logo'));
    }
  }
}

/**
 * Phase 3 page template variables preprocessor.
 */
function hex_re_process_page(&$vars) {
  // Carry over default body classes with some cleaning.
  if (!empty($vars['body_classes'])) {
    foreach (explode(' ', trim($vars['body_classes'])) as $body_class) {
      // Core assumes 'no-sidebars' if the theme doesn't implement 'left' or 'right' regions.
      if ($body_class == 'no-sidebars' && !isset($vars['left'], $vars['right'])) {
        continue;
      }
      $vars['classes_array'][] = $body_class;
    }
    $vars['body_classes'] = implode(' ', $vars['classes_array']);
  }
}

/**
 * Return a themed set of status and/or error messages. The messages are grouped
 * by type. Converted into a template.
 *
 * @param $display
 *   (optional) Set to 'status' or 'error' to display only messages of that type.
 */
function hex_preprocess_status_messages(&$vars) {
  $vars['messages'] = drupal_get_messages($vars['display']);
  // Sort with 'status' first then 'error'. It's friendlier that way.
  krsort($vars['messages']);
}

/**
 * Return a themed form element. Converted to a template
 *
 * @param element
 *   An associative array containing the properties of the element.
 *   Properties used: title, description, id, required
 * @param $value
 *   The form element's data.
 */
function hex_preprocess_form_element(&$vars) {
  $element = $vars['element'];
  $vars['title']       = !empty($element['#title']) ? filter_xss_admin($element['#title']) : '';
  $vars['description'] = !empty($element['#description']) ? $element['#description'] : '';
  $vars['required']    = !empty($element['#required']) ? $element['#required'] : FALSE;

  if (!empty($element['#id'])) {
    $vars['html_elements']['label']['#attributes']['for'] = $element['#id'];
  }
  $vars['classes_array'][] = 'form-item';
  if (!empty($element['#id'])) {
    $vars['id_attribute'] = $element['#id'] . '-wrapper';
  }
  elseif (!empty($element['#name'])) {
    $name = $element['#name'];
    // Clean out possible brackets.
    if (strpos($name, '[') !== FALSE) {
      $name = str_replace(array('[', ']') ,'' , substr($name, strpos($name, '[')));
    }
    $vars['id_attribute'] = 'name-' . $name . '-wrapper';
  }
  if (isset($element['#attributes']['class'])) {
    // Add a class for this wrapper since there's no way to select parents.
    foreach (explode(' ', $element['#attributes']['class']) as $element_class) {
      $vars['classes_array'][] = $element_class . '-wrapper';
    }
  }
  if (isset($element['#type'])) {
    $vars['classes_array'][] = 'form-' . $element['#type'] . '-wrapper';
    $vars['template files'][] = 'form-element-' . $element['#type'];
  }

  // There tends to be repeats. Use unique values.
  $vars['classes_array'] = array_unique($vars['classes_array']);

}
