<?php

/**
 * Contextually adds 960 Grid System classes.
 *
 * The first parameter passed is the *default class*. All other parameters must
 * be set in pairs like so: "$variable, 3". The variable can be anything available
 * within a template file and the integer is the width set for the adjacent box
 * containing that variable.
 *
 *  class="<?php print ns('grid-16', $left, 6); ?>"
 *
 * If $var_a contains data, the next parameter (integer) will be subtracted from
 * the default class. See the README.txt file.
 */
function ns() {
  $args = func_get_args();
  $default = array_shift($args);
  return ns_contextual_class($default, $args);
}

/**
 * Serves the same purpose as the ns() function but prints it out directly.
 * 
 *  class="<?php nsp('grid-16', $left, 6); ?>"
 * 
 * @see ns()
 */
function nsp() {
  $args = func_get_args();
  $default = array_shift($args);
  print ns_contextual_class($default, $args);
}

/**
 * Process a given $default class based on the $context.
 * 
 * @see ns()
 * @see nsp()
 */
function ns_contextual_class($default, $context) {
  // Get the type of class, i.e., 'grid', 'pull', 'push', etc.
  // Also get the default unit for the type to be procesed and returned.
  list($type, $return_unit) = explode('-', $default);

  // Process the conditions.
  $flip_states = array('var' => 'int', 'int' => 'var');
  $state = 'var';
  foreach ($context as $c) {
    if ($state == 'var') {
      $var_state = !empty($c);
    }
    elseif ($var_state) {
      $return_unit = $return_unit - $c;
    }
    $state = $flip_states[$state];
  }

  $output = '';
  // Anything below a value of 1 is not needed.
  if ($return_unit > 0) {
    $output = $type . '-' . $return_unit;
  }

  return $output;
}
