<?php

/**
 * Group multiple block regions into one.
 */
function region_groups_preprocess_page(&$vars) {

  // Used to ensure valid regions are used.
  // Group keys can be anything but the regions must be correct.
  $theme_regions = array_keys(system_region_list(hex_active_theme()));

  if ($region_groups = hex_theme_info('region groups', array())) {
    foreach ($region_groups as $group_key => $regions) {
      $region_output = '';
      foreach ($regions as $region) {
        if (isset($vars[$region]) && in_array($region, $theme_regions)) {
          $region_output .= $vars[$region];
        }
      }
      $vars[$group_key] = $region_output;
    }

    // Redo the layout and body classes variable since the left and right
    // regions could be a region group. Redo of template_preprocess_page().
    if (isset($region_groups['left']) || isset($region_groups['right'])) {
      // Set up layout variable.
      $vars['layout'] = 'none';
      if (!empty($vars['left'])) {
        $vars['layout'] = 'left';
      }
      if (!empty($vars['right'])) {
        $vars['layout'] = ($vars['layout'] == 'left') ? 'both' : 'right';
      }

      $body_classes = explode(' ', $vars['body_classes']);
      foreach ($body_classes as $i => $class) {
        // Remove classes related to sidebars.
        if (in_array($class, array('two-sidebars', 'no-sidebars', 'one-sidebar', 'sidebar-left', 'sidebar-right'))) {
          unset($body_classes[$i]);
        }
      }
      if ($vars['layout'] == 'both') {
        $body_classes[] = 'two-sidebars';
      }
      elseif ($vars['layout'] == 'none') {
        $body_classes[] = 'no-sidebars';
      }
      else {
        $body_classes[] = 'one-sidebar sidebar-'. $vars['layout'];
      }
      $vars['body_classes'] = implode(' ', $body_classes);
    }
  }
}

/**
 * Pass in a region and it will return the group it belongs to.
 */
function region_groups_get_group($region) {
  foreach (hex_theme_info('region groups', array()) as $group => $regions) {
    if (in_array($region, $regions)) {
      return $group;
    }
  }
  return NULL;
}

