
/**
 * fxTabs based on Accessible Tabs with the following modifications:
 *
 * * Better targeting of ul headers by adding a configurable "tabheadClass" class.
 * * Fixed bug where the "currentClass" was not used from the passed parameters.
 * * Remembers visibility state for specific tabs. Depends on jquery.cookie.js.
 * * Added an option to target a tab group on page load.
 * * Option to equalize vertical height. Depends on jquery.vjustify.js.
 *
 *
 * YAML Tabs - jQuery plugin for accessible, unobtrusive tabs
 * Build to seemlessly work with the CCS-Framework YAML (yaml.de) not depending on YAML though
 * @requires jQuery v1.0.3
 *
 * http://blog.ginader.de/dev/yamltabs/index.php
 *
 * Copyright (c) 2007 Dirk Ginader (ginader.de)
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 * Version: 1.1.1
 *
 * History:
 * * 1.0 initial release
 * * 1.1 added a lot of Accessibility enhancements
 * * * rewrite to use "fn.extend" structure
 * * * added check for existing ids on the content containers to use to proper anchors in the tabs
 * * 1.1.1 changed the headline markup. thanks to Mike Davies for the hint.
 */

jQuery.fn.fxTabs = function(p) {
  p = jQuery.extend({
    activate: null,                       // The tab set to show on page load. Use a numeric position starting at 0 or a html ID pointing to the
                                          // header or content without the hash. Setting this to null will restore the previous state.
    applyClass: 'fx-tabs',                // Classname to apply to the passed object. Use as a contextual CSS selector for styling.
    currentClass: 'fx-active',            // Classname to apply to the LI of the selected tab.
    tabheadClass: 'fx-titles',            // Classname to apply to the UL of the tab group.
    contentClass: 'fx-contents',          // Classname to apply to the content wrapper.
    headerSelect: '.block-title',         // Query Selector of the Elements to Transform the Tabs-Navigation from (originals are removed).
    contentSelect: '.block',              // Query Selector of the Elements to be treated as the Tab Body.
    fx: 'fadeIn',                         // can be "fadeIn", "slideDown", "show".
    fxspeed: 'normal',                    // speed (String|Number): "slow", "normal", or "fast") or the number of milliseconds to run the animation.
    currentTabTag: 'h2',                  // A heading tag for the currently active tab. This is used for screenreaders and will be hidden.
    currentInfoText: 'current tab: ',     // text to indicate for screenreaders which tab is the current one
    currentInfoPosition: 'prepend',       // Definition where to insert the Info Text. Can be either "prepend" or "append"
    currentInfoClass: 'fx-current-info',  // Class to apply to the span wrapping the CurrentInfoText.
    highlightTrigger: '.active, .active-trail, .active-menu', // Query Selector to trigger the next option when there's a matche in the tab content.
    highlightClass: 'page-active',        // Classname to apply to the LI tab head and tab body.
    vjustify: true                        // Justifies the height of each tab body.
  },p);

  var c = $(this).addClass(p.applyClass);
  $(p.contentSelect, c).wrapAll('<div class="'+p.contentClass+'"></div>');

  var tabsId = $(this).attr('id');
  var activateId = null;
  var initVis = 0;

  if (p.activate == null) {
    activateId = $.cookie('fxTabs:'+tabsId);
  }
  else if (typeof(p.activate) == 'string') {
    activateId = p.activate;
  }
  else if (typeof(p.activate) == 'number') {
    initVis = p.activate;
  }

  var idIndex  = [];
  var contentAnchor = 'accessibletabscontent'+ new Date().getTime();
  var tabsAnchor    = 'accessibletabs'+ new Date().getTime();
  var list = '';

  $(c).find(p.headerSelect).each(function(i){
    var headerId  = $(this).attr('id');
    var contentMatch = $(p.contentSelect, c).eq(i);
    var listClass = '';
    idIndex.push(headerId.length ? headerId : contentMatch.attr('id'));
    if (idIndex[i] == activateId) {
      initVis = i;
    }
    if (contentMatch.find(p.highlightTrigger).length !== 0) {
      listClass = ' class="'+p.highlightClass+'"';
      contentMatch.addClass(p.highlightClass);
    }
    list += '<li'+listClass+'><a href="#'+contentAnchor+'">'+$(this).text()+'</a></li>\n';
    $(this).remove();
  });

  $(c).prepend('<ul id="'+tabsAnchor+'" class="'+p.tabheadClass+'">'+list+'</ul>');
  $(c).find(p.contentSelect+':not(:eq('+initVis+'))').hide();
  $(c).find(p.contentSelect+':first')
    .before('<'+p.currentTabTag+' class="accessibletabsheader"><a tabindex="0" name="'+contentAnchor+'" id="'+contentAnchor+'">'+$(c).find("ul>li").eq(initVis).text()+'</a></'+p.currentTabTag+'>');
  $(c).find('ul.'+p.tabheadClass+'>li').eq(initVis).addClass(p.currentClass)
    .find('a')[p.currentInfoPosition]('<span class="'+p.currentInfoClass+'">'+p.currentInfoText+'</span>');

  $(c).find('ul.'+p.tabheadClass+'>li>a').each(function(i){
    $(this).click(function(event){
      event.preventDefault();
      $(c).find('ul.'+p.tabheadClass+'>li.'+p.currentClass).removeClass(p.currentClass)
        .find("span."+p.currentInfoClass).remove();
      $(this).blur();
      $(c).find(p.contentSelect+':visible').hide();
      $(c).find(p.contentSelect).eq(i)[p.fx](p.fxspeed);
      $( '#'+contentAnchor ).text( $(this).text() ).focus();
      $(this)[p.currentInfoPosition]('<span class="'+p.currentInfoClass+'">'+p.currentInfoText+'</span>')
        .parent().addClass(p.currentClass);
      if (tabsId != '') {
        $.cookie('fxTabs:'+tabsId, idIndex[i], { expires: 3, path: '/'});
      }
    });
  });

  if (p.vjustify) {
    $('.'+p.contentClass+' '+p.contentSelect, this).vjustify();
  }

  return this;
}
