<?php


/**
 * Block region template variables re-processor.
 */
function regionfx_re_process_blocks(&$vars) {
  // Region fx!
  if (!empty($vars['content'])) {
    regionfx_attach('#' . hex_filter_attributes('id', $vars['id_attribute']), $vars['region']);
  }
}

/**
 * Page template variables re-processor.
 */
function regionfx_preprocess_page(&$vars) {
  // Collect fx scripts. Set from block regions most of the time.
  if (regionfx_get_behaviors()) {
    $vars['scripts'] = drupal_get_js();
  }
}

/**
 * Add settings for behaviors.
 *
 * @param $jq_select
 *  The CSS selector to target the markup. HTML id's are recommended but it
 *  can be anything jQuery understands.
 * @param $region
 *  Block region name.
 */
function regionfx_attach($jq_select = NULL, $region = NULL) {
  static $attached = array();

  if (isset($jq_select) && isset($region)) {

    if ($fx_key = regionfx_key($region)) {
      // Make sure the fx plug-in is enabled.
      if (in_array($fx_key, hex_plugin_info('regionfx', 'active_dependents', array()))) {

        $fx_info = hex_theme_info($fx_key, array());
        if (isset($fx_info[$region])) {
          foreach ($fx_info[$region] as $setting => $value) {
            // Force type conversions. This must be done since .info doesn't
            // always convert to the expected type.
            if (is_numeric($value)) {
              $value = (int) $value;
            }
            elseif ($value == 'true') {
              $value = TRUE;
            }
            elseif ($value == 'false') {
              $value = FALSE;
            }
            $block_settings_array[] = $setting . ':' . drupal_to_js($value);
          }
        }

        $block_settings = '';
        if (!empty($block_settings_array)) {
          $block_settings = '{' . implode(',', $block_settings_array) . '}';
        }

        $attached[$fx_key][$jq_select] = $block_settings;
      }
    }
  }

  return $attached;
}

/**
 * Collect everything added and include any files that are needed. Do not call
 * directly.
 */
function regionfx_get_behaviors() {
  $fx_added = FALSE;
  if ($fx_attached = regionfx_attach()) {
    foreach (array_keys($fx_attached) as $fx_key) {
      foreach (hex_plugin_info($fx_key, 'scripts', array()) as $script) {
        if ($script_path = hex_path_to_file($script, 'jquery', 'plugin')) {
          drupal_add_js($script_path, 'theme');
        }
      }
    }
    $script = 'if(Drupal.jsEnabled){$(function(){';
    foreach ($fx_attached as $fx_key => $select_settings) {
      foreach ($select_settings as $jq_select => $settings) {
        $script .= "$('$jq_select').$fx_key($settings);";
      }
    }
    $script .= "});}";
    drupal_add_js($script, 'inline');
    $fx_added = TRUE;
  }
  return $fx_added;
}

/**
 * Pass in a region key and it will return the region fx plug-in if it matches.
 */
function regionfx_key($region_key) {
  $fx_key = '';
  foreach (hex_theme_info('regionfx', array()) as $fx_plugin => $regions) {
    if (in_array($region_key, $regions)) {
      $fx_key = $fx_plugin;
      break;
    }
  }
  return $fx_key;
}
