<?php

/**
 * Implementation of HOOK_theme().
 */
function theme_wrapper_theme() {

  // General use theme wrapper. Alternate wrappers can be created by creating
  // a function or template with the pattern prefix and enabling a switch
  // from a variable process function.
  $hooks['wrapper'] = array(
    'arguments' => array(
      'content'            => NULL,
      'wrapper_attributes' => array(),
      'inner_variables'    => array(),
    ),
    'template' => 'wrapper',
    'pattern'  => 'wrapper__',
    'path'     => hex_plugin_path('theme_wrapper'),
  );

  return $hooks;
}

/**
 * Implementation of HOOK_preprocess_alter(). A hexagon supplied hook.
 */
function theme_wrapper_registry_preprocess_alter(&$preprocess, $info) {
  // Keep this quick. Don't add extra preprocess functions.
  if ($info->hook_base == 'wrapper') {
    foreach ($preprocess as $i => $_preprocess) {
      if (strpos($_preprocess, '_wrapper') === FALSE) {
        unset($preprocess[$i]);
      }
    }
  }
}

/**
 * Maps the wrapper attributes back onto the standard html_elements array.
 */
function template_preprocess_wrapper(&$variables, $hook) {

  if (!empty($variables['wrapper_attributes'])) {
    foreach ($variables['wrapper_attributes'] as $attr => $values) {
      if (is_array($values)) {
        foreach ($values as $value) {
          $variables['html_elements']['#attributes'][$attr][] = $value;
        }
      }
      elseif (!empty($values)) {
        $variables['html_elements']['#attributes'][$attr] = $values;
      }
    }
  }

}

/**
 * Post render callback.
 */
function theme_wrapper_post_render_callback(&$variables, $contents) {

  // Wrapping the output must be explicitly switched on. Adding wrapper naming suggestions will also triger it.
  if (!empty($contents) && (!empty($variables['wrap_output']))) {
    // Prevent recursive wrapping and don't wrapper the outter most containers.
    if (strpos($variables['hook_meta']->hook_base, 'wrapper') === FALSE || !in_array($variables['hook_meta']->hook, array('page', 'book_export_html'))) {
      // Through preprocess functions, the theming hook can set its own wrappers
      // which will be based on the pattern prefix set for the "wrapper" theming
      // hook. This is bascially the same idea behind template naming suggestions
      // but this allows separation of the inner contents from the surrounding mark-up.
      // The order is FILO (first in, last out).
      $wrapper_suggestions = array();
      if (isset($variables['wrapper_suggestions'])) {
        $wrapper_suggestions = $variables['wrapper_suggestions'];
      }
      if (isset($variables['wrapper_suggestion'])) {
        $wrapper_suggestions[] = $variables['wrapper_suggestion'];
      }

      $hook_candidates = array();
      foreach (array_reverse($wrapper_suggestions) as $wrapper_suggestion) {
        $hook_candidates[] = 'wrapper__' . str_replace('-', '_', $wrapper_suggestion);
      }

      // Supply some defaults.
      $hook_candidates[] = 'wrapper__' . $variables['hook_meta']->hook_base;
      $hook_candidates[] = 'wrapper';

      // Pass along any markup attributes.
      $attributes = array();
      if (isset($variables['wrapper_attributes'])) {
        $attributes = $variables['wrapper_attributes'];
      }

      $contents = theme($hook_candidates, $contents, $attributes, $variables);
    }
  }

  return $contents;
}
